# Raster Loader roadmap

## Vision

The Raster Loader is an open-source tool for loading GIS raster data to standard
cloud-based data warehouses that don't natively support raster data.

## Goals for version 1.0.0

Goals for version 1.0.0 of Raster Loader include:

For loading raster data:

- Support loading raster data from a local file and file archives (ZIP)
- Support loading raster data from a URL
- Support loading raster data from a cloud storage bucket (such as AWS S3)

For storing raster data in the cloud:

- Support storing raster data in GCP, AWS, and Azure data warehouses

## Goals for future versions

Goals for future versions include:

- Add improved error handling
- Make the CLI more user-friendly
